#!/bin/sh
###########################################
#                                         #
#  MinimServer Synology package           #
#                                         #
###########################################

TMP_DIR="/tmp/MinimServer"
DEBUG_FILE="${TMP_DIR}/minimserver-debug"
if [ -f "$DEBUG_FILE" ]; then
	exec >>$DEBUG_FILE 2>&1
	set -x
fi
APP_DATA="appData"
LOG_FILE="${TMP_DIR}/minimserver-log"
PACKAGE_LOCATION="/var/packages/${SYNOPKG_PKGNAME}/target"
if [ -f "/etc/samba/smb.conf" ]; then
	# location for DSM 6.0 and later
	smb_conf="/etc/samba/smb.conf"
elif [ -f "/usr/syno/etc/smb.conf" ]; then
	# location for DSM 5.2 and earlier
	smb_conf="/usr/syno/etc/smb.conf"
fi
if [ -n "$smb_conf" ]; then
	minim_share=$(cat "$smb_conf" | sed -r '/\/'MinimServer'$/!d;s/^.*path=(\/volume[0-9]{1,4}\/'MinimServer').*$/\1/')
fi
if [ -n "$minim_share" ]; then
	# shared folder already exists and might not be on the package installed volume
	VOLUME=$(dirname "$minim_share")
	MINIM_HOME="$minim_share"
else
	appstore_target=$(readlink "${PACKAGE_LOCATION}")
	if [ ! -z "$appstore_target" ]; then
		appstore_dir=$(dirname "$appstore_target")
		VOLUME=$(dirname "$appstore_dir")
	else
		VOLUME=$(/usr/syno/bin/servicetool --get-alive-volume)
	fi
	MINIM_HOME="${VOLUME}/${SYNOPKG_PKGNAME}"
fi
[ ! -e "${TMP_DIR}" ] && mkdir "${TMP_DIR}"

debug ()
{
	DATE=$(date +"%a %d %b %T")
	echo "${DATE} $1" >>$LOG_FILE
}

UIFILES_DIR=$(dirname $0)
package_version=$(grep "version=" "${UIFILES_DIR}"/../INFO | cut -f2 -d'"' | cut -f1 -d'-')
config_version=$(grep "minimserver\\.configVersion" ${MINIM_HOME}/appData/minimserver.config | cut -f2- -d'=' | sed 's/ //g')
debug "update_uifile.sh: package_version=$package_version config_version=$config_version"
if [ "0.8." = "${config_version:0:4}" ]; then
	cat >$SYNOPKG_TEMP_LOGFILE <<EOF
[{
    "step_title": "Confirm update to MinimServer $package_version",
    "items":
    [{
        "type": "textfield",
        "desc": "You are updating to MinimServer $package_version from MinimServer 0.8. Read this page carefully before proceeding.",
        "subitems": [ ]
    },{
        "type": "textfield",
        "desc": "MinimServer $package_version is installed as a free version (Starter Edition) with the option of purchasing a license to enable additional features. Some features that were free to use in MinimServer 0.8 now require a paid license. For details of these changes, see minimserver.com/licensing.html. You can try the full version of MinimServer $package_version free of charge for 30 days.",
        "subitems": [ ]
    },{
        "type": "textfield",
        "desc": "Installing MinimServer $package_version will replace your current version of MinimServer. To continue with your installation of MinimServer $package_version, click the Next button below. To cancel your installation of MinimServer $package_version and continue using your current version of MinimServer, close this dialog.",
        "subitems": [ ]
    }]
}]
EOF
fi
